===============================
scibag
===============================

Data science meta-package

This package used to be called pylab but was renamed due to name collision with the pylab interface of matplotlib.
